@@ -35,8 +35,6 @@ static const PlainGameDescriptor draciGames[] = {
 
 namespace Draci {
 
-using Common::GUIO_NONE;
-
 const ADGameDescription gameDescriptions[] = {
 	{
 		"draci",
@@ -45,7 +43,7 @@ const ADGameDescription gameDescriptions[] = {
 		Common::EN_ANY,
 		Common::kPlatformPC,
 		ADGF_NO_FLAGS,
-		GUIO_NONE
+		GUIO0()
 	},
 
 	{
@@ -55,7 +53,7 @@ const ADGameDescription gameDescriptions[] = {
 		Common::CZ_CZE,
 		Common::kPlatformPC,
 		ADGF_NO_FLAGS,
-		GUIO_NONE
+		GUIO0()
 	},
 
 	{
@@ -65,7 +63,7 @@ const ADGameDescription gameDescriptions[] = {
 		Common::PL_POL,
 		Common::kPlatformPC,
 		ADGF_NO_FLAGS,
-		GUIO_NONE
+		GUIO0()
 	},
 
 	{
@@ -75,7 +73,7 @@ const ADGameDescription gameDescriptions[] = {
 		Common::DE_DEU,
 		Common::kPlatformPC,
 		ADGF_NO_FLAGS,
-		GUIO_NONE
+		GUIO0()
 	},
 
 	AD_TABLE_END_MARKER
@@ -163,8 +161,6 @@ SaveStateDescriptor DraciMetaEngine::querySaveMetaInfos(const char *target, int
 
 		// Create the return descriptor
 		SaveStateDescriptor desc(slot, header.saveName);
-		desc.setDeletableFlag(true);
-		desc.setWriteProtectedFlag(false);
 		desc.setThumbnail(header.thumbnail);
 
 		int day = (header.date >> 24) & 0xFF;
