@@ -122,6 +122,7 @@ private:
 class Surface {
 public:
 	Surface(uint16 width, uint16 height, uint8 bpp, byte *vidMem = 0);
+	Surface(uint16 width, uint16 height, uint8 bpp, const byte *vidMem);
 	~Surface();
 
 	uint16 getWidth () const;
@@ -157,6 +158,7 @@ public:
 
 	void putPixel(uint16 x, uint16 y, uint32 color);
 	void drawLine(uint16 x0, uint16 y0, uint16 x1, uint16 y1, uint32 color);
+	void drawRect(uint16 left, uint16 top, uint16 right, uint16 bottom, uint32 color);
 	void drawCircle(uint16 x0, uint16 y0, uint16 radius, uint32 color, int16 pattern = 0);
 
 	void blitToScreen(uint16 left, uint16 top, uint16 right, uint16 bottom, uint16 x, uint16 y) const;
