@@ -219,7 +219,7 @@ void GfxMenu::kernelAddEntry(Common::String title, Common::String content, reg_t
 			}
 		}
 		itemEntry->textVmPtr = contentVmPtr;
-		itemEntry->textVmPtr.offset += beginPos;
+		itemEntry->textVmPtr.incOffset(beginPos);
 
 		if (rightAlignedPos) {
 			rightAlignedPos++;
@@ -286,7 +286,7 @@ void GfxMenu::kernelSetAttribute(uint16 menuId, uint16 itemId, uint16 attributeI
 
 	switch (attributeId) {
 	case SCI_MENU_ATTRIBUTE_ENABLED:
-		itemEntry->enabled = value.isNull() ? false : true;
+		itemEntry->enabled = !value.isNull();
 		break;
 	case SCI_MENU_ATTRIBUTE_SAID:
 		itemEntry->saidVmPtr = value;
@@ -297,13 +297,13 @@ void GfxMenu::kernelSetAttribute(uint16 menuId, uint16 itemId, uint16 attributeI
 		// We assume here that no script ever creates a separatorLine dynamically
 		break;
 	case SCI_MENU_ATTRIBUTE_KEYPRESS:
-		itemEntry->keyPress = tolower(value.offset);
+		itemEntry->keyPress = tolower(value.getOffset());
 		itemEntry->keyModifier = 0;
 		// TODO: Find out how modifier is handled
-		debug("setAttr keypress %X %X", value.segment, value.offset);
+		debug("setAttr keypress %X %X", value.getSegment(), value.getOffset());
 		break;
 	case SCI_MENU_ATTRIBUTE_TAG:
-		itemEntry->tag = value.offset;
+		itemEntry->tag = value.getOffset();
 		break;
 	default:
 		// Happens when loading a game in LSL3 - attribute 1A
@@ -606,7 +606,7 @@ void GfxMenu::drawMenu(uint16 oldMenuId, uint16 newMenuId) {
 		listItemEntry = *listItemIterator;
 		if (listItemEntry->menuId == newMenuId) {
 			if (!listItemEntry->separatorLine) {
-				_ports->textGreyedOutput(listItemEntry->enabled ? false : true);
+				_ports->textGreyedOutput(!listItemEntry->enabled);
 				_ports->moveTo(_menuRect.left, topPos);
 				_text16->DrawString(listItemEntry->textSplit.c_str());
 				_ports->moveTo(_menuRect.right - listItemEntry->textRightAlignedWidth - 5, topPos);
