@@ -37,8 +37,6 @@ static const PlainGameDescriptor toucheGames[] = {
 
 namespace Touche {
 
-using Common::GUIO_NONE;
-
 static const ADGameDescription gameDescriptions[] = {
 	{ // retail version
 		"touche",
@@ -47,7 +45,7 @@ static const ADGameDescription gameDescriptions[] = {
 		Common::EN_ANY,
 		Common::kPlatformPC,
 		ADGF_NO_FLAGS,
-		GUIO_NONE
+		GUIO0()
 	},
 	{ // retail version - tracker item #1601818
 		"touche",
@@ -56,7 +54,7 @@ static const ADGameDescription gameDescriptions[] = {
 		Common::EN_ANY,
 		Common::kPlatformPC,
 		ADGF_NO_FLAGS,
-		GUIO_NONE
+		GUIO0()
 	},
 	{ // retail version
 		"touche",
@@ -65,7 +63,7 @@ static const ADGameDescription gameDescriptions[] = {
 		Common::FR_FRA,
 		Common::kPlatformPC,
 		ADGF_NO_FLAGS,
-		GUIO_NONE
+		GUIO0()
 	},
 	{ // retail version - tracker item #1598643
 		"touche",
@@ -74,7 +72,7 @@ static const ADGameDescription gameDescriptions[] = {
 		Common::DE_DEU,
 		Common::kPlatformPC,
 		ADGF_NO_FLAGS,
-		GUIO_NONE
+		GUIO0()
 	},
 	{ // retail version - tracker item #1681643
 		"touche",
@@ -83,7 +81,7 @@ static const ADGameDescription gameDescriptions[] = {
 		Common::ES_ESP,
 		Common::kPlatformPC,
 		ADGF_NO_FLAGS,
-		GUIO_NONE
+		GUIO0()
 	},
 	{ // fan-made translation (http://www.iagtg.net/) - tracker item #1602360
 		"touche",
@@ -92,7 +90,7 @@ static const ADGameDescription gameDescriptions[] = {
 		Common::IT_ITA,
 		Common::kPlatformPC,
 		ADGF_NO_FLAGS,
-		GUIO_NONE
+		GUIO0()
 	},
 	{ // retail version - tracker item #1800500
 		"touche",
@@ -101,7 +99,7 @@ static const ADGameDescription gameDescriptions[] = {
 		Common::PL_POL,
 		Common::kPlatformPC,
 		ADGF_NO_FLAGS,
-		GUIO_NONE
+		GUIO0()
 	},
 	{ // demo version
 		"touche",
@@ -110,7 +108,7 @@ static const ADGameDescription gameDescriptions[] = {
 		Common::EN_ANY,
 		Common::kPlatformPC,
 		ADGF_DEMO,
-		GUIO_NONE
+		GUIO0()
 	},
 	AD_TABLE_END_MARKER
 };
