@@ -103,30 +103,42 @@ GuiManager::~GuiManager() {
 void GuiManager::initKeymap() {
 	using namespace Common;
 
-	bool tmp;
 	Keymapper *mapper = _system->getEventManager()->getKeymapper();
 
 	// Do not try to recreate same keymap over again
-	if (mapper->getKeymap("gui", tmp) != 0)
+	if (mapper->getKeymap(kGuiKeymapName) != 0)
 		return;
 
 	Action *act;
-	Keymap *guiMap = new Keymap("gui");
+	Keymap *guiMap = new Keymap(kGuiKeymapName);
 
-	act = new Action(guiMap, "CLOS", _("Close"), kGenericActionType, kStartKeyType);
+	act = new Action(guiMap, "CLOS", _("Close"));
 	act->addKeyEvent(KeyState(KEYCODE_ESCAPE, ASCII_ESCAPE, 0));
 
 	act = new Action(guiMap, "CLIK", _("Mouse click"));
 	act->addLeftClickEvent();
 
-	act = new Action(guiMap, "VIRT", _("Display keyboard"), kVirtualKeyboardActionType);
-	act->addKeyEvent(KeyState(KEYCODE_F7, ASCII_F7, 0));
+#ifdef ENABLE_VKEYBD
+	act = new Action(guiMap, "VIRT", _("Display keyboard"));
+	act->addEvent(EVENT_VIRTUAL_KEYBOARD);
+#endif
 
-	act = new Action(guiMap, "REMP", _("Remap keys"), kKeyRemapActionType);
-	act->addKeyEvent(KeyState(KEYCODE_F8, ASCII_F8, 0));
+	act = new Action(guiMap, "REMP", _("Remap keys"));
+	act->addEvent(EVENT_KEYMAPPER_REMAP);
+
+	act = new Action(guiMap, "FULS", _("Toggle FullScreen"));
+	act->addKeyEvent(KeyState(KEYCODE_RETURN, ASCII_RETURN, KBD_ALT));
 
 	mapper->addGlobalKeymap(guiMap);
 }
+
+void GuiManager::pushKeymap() {
+	_system->getEventManager()->getKeymapper()->pushKeymap(Common::kGuiKeymapName);
+}
+
+void GuiManager::popKeymap() {
+	_system->getEventManager()->getKeymapper()->popKeymap(Common::kGuiKeymapName);
+}
 #endif
 
 bool GuiManager::loadNewTheme(Common::String id, ThemeEngine::GraphicsMode gfx, bool forced) {
@@ -176,7 +188,7 @@ bool GuiManager::loadNewTheme(Common::String id, ThemeEngine::GraphicsMode gfx,
 	}
 
 	// refresh all dialogs
-	for (int i = 0; i < _dialogStack.size(); ++i)
+	for (DialogStack::size_type i = 0; i < _dialogStack.size(); ++i)
 		_dialogStack[i]->reflowLayout();
 
 	// We need to redraw immediately. Otherwise
@@ -190,7 +202,6 @@ bool GuiManager::loadNewTheme(Common::String id, ThemeEngine::GraphicsMode gfx,
 }
 
 void GuiManager::redraw() {
-	int i;
 	ThemeEngine::ShadingStyle shading;
 
 	if (_redrawStatus == kRedrawDisabled || _dialogStack.empty())
@@ -211,7 +222,7 @@ void GuiManager::redraw() {
 			_theme->clearAll();
 			_theme->openDialog(true, ThemeEngine::kShadingNone);
 
-			for (i = 0; i < _dialogStack.size() - 1; i++)
+			for (DialogStack::size_type i = 0; i < _dialogStack.size() - 1; i++)
 				_dialogStack[i]->drawDialog();
 
 			_theme->finishBuffering();
@@ -270,19 +281,9 @@ void GuiManager::runLoop() {
 	uint32 lastRedraw = 0;
 	const uint32 waitTime = 1000 / 45;
 
-#ifdef ENABLE_KEYMAPPER
-	// Due to circular reference with event manager and GUI
-	// we cannot init keymap on the GUI creation. Thus, let's
-	// try to do it on every launch, checking whether the
-	// map is already existing
-	initKeymap();
-
-	eventMan->getKeymapper()->pushKeymap("gui");
-#endif
-
 	bool tooltipCheck = false;
 
-	while (!_dialogStack.empty() && activeDialog == getTopDialog()) {
+	while (!_dialogStack.empty() && activeDialog == getTopDialog() && !eventMan->shouldQuit()) {
 		redraw();
 
 		// Don't "tickle" the dialog until the theme has had a chance
@@ -361,12 +362,13 @@ void GuiManager::runLoop() {
 			case Common::EVENT_WHEELDOWN:
 				activeDialog->handleMouseWheel(mouse.x, mouse.y, 1);
 				break;
-			case Common::EVENT_QUIT:
-				return;
 			case Common::EVENT_SCREEN_CHANGED:
 				screenChange();
 				break;
 			default:
+#ifdef ENABLE_KEYMAPPER
+				activeDialog->handleOtherEvent(event);
+#endif
 				break;
 			}
 
@@ -379,7 +381,7 @@ void GuiManager::runLoop() {
 
 		if (tooltipCheck && _lastMousePosition.time + kTooltipDelay < _system->getMillis()) {
 			Widget *wdg = activeDialog->findWidget(_lastMousePosition.x, _lastMousePosition.y);
-			if (wdg && wdg->getTooltip()) {
+			if (wdg && wdg->getTooltip() && !(wdg->getFlags() & WIDGET_PRESSED)) {
 				Tooltip *tooltip = new Tooltip();
 				tooltip->setup(activeDialog, wdg, _lastMousePosition.x, _lastMousePosition.y);
 				tooltip->runModal();
@@ -391,9 +393,16 @@ void GuiManager::runLoop() {
 		_system->delayMillis(10);
 	}
 
-#ifdef ENABLE_KEYMAPPER
-	eventMan->getKeymapper()->popKeymap();
-#endif
+	// WORKAROUND: When quitting we might not properly close the dialogs on
+	// the dialog stack, thus we do this here to avoid any problems.
+	// This is most noticable in bug #3481395 "LAUNCHER: Can't quit from unsupported game dialog".
+	// It seems that Dialog::runModal never removes the dialog from the dialog
+	// stack, thus if the dialog does not call Dialog::close to close itself
+	// it will never be removed. Since we can have multiple run loops being
+	// called we cannot rely on catching EVENT_QUIT in the event loop above,
+	// since it would only catch it for the top run loop.
+	if (eventMan->shouldQuit() && activeDialog == getTopDialog())
+		getTopDialog()->close();
 
 	if (didSaveState) {
 		_theme->disable();
@@ -405,6 +414,10 @@ void GuiManager::runLoop() {
 #pragma mark -
 
 void GuiManager::saveState() {
+#ifdef ENABLE_KEYMAPPER
+	initKeymap();
+	pushKeymap();
+#endif
 	// Backup old cursor
 	_lastClick.x = _lastClick.y = 0;
 	_lastClick.time = 0;
@@ -414,6 +427,9 @@ void GuiManager::saveState() {
 }
 
 void GuiManager::restoreState() {
+#ifdef ENABLE_KEYMAPPER
+	popKeymap();
+#endif
 	if (_useStdCursor) {
 		CursorMan.popCursor();
 		CursorMan.popCursorPalette();
@@ -425,6 +441,11 @@ void GuiManager::restoreState() {
 }
 
 void GuiManager::openDialog(Dialog *dialog) {
+	dialog->receivedFocus();
+
+	if (!_dialogStack.empty())
+		getTopDialog()->lostFocus();
+
 	_dialogStack.push(dialog);
 	if (_redrawStatus != kRedrawFull)
 		_redrawStatus = kRedrawOpenDialog;
@@ -442,7 +463,11 @@ void GuiManager::closeTopDialog() {
 		return;
 
 	// Remove the dialog from the stack
-	_dialogStack.pop();
+	_dialogStack.pop()->lostFocus();
+
+	if (!_dialogStack.empty())
+		getTopDialog()->receivedFocus();
+
 	if (_redrawStatus != kRedrawFull)
 		_redrawStatus = kRedrawCloseDialog;
 
@@ -501,7 +526,7 @@ void GuiManager::screenChange() {
 	_theme->refresh();
 
 	// refresh all dialogs
-	for (int i = 0; i < _dialogStack.size(); ++i) {
+	for (DialogStack::size_type i = 0; i < _dialogStack.size(); ++i) {
 		_dialogStack[i]->reflowLayout();
 	}
 	// We need to redraw immediately. Otherwise
